==> skrooge_0.2.9.orig.tar.gz: skrooge-0.2.9/skrooge_scheduled/skgscheduledboardwidget.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSCHEDULEDBOARDWIDGET_H
#define SKGSCHEDULEDBOARDWIDGET_H
/** @file
* This file is Skrooge plugin for bank management.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/
#include "ui_skgscheduledpluginwidget_board.h"
#include "skgwidget.h"

/**
 * This file is Skrooge plugin for bank management
 */
class SKGScheduledBoardWidget : public SKGWidget
{
        Q_OBJECT

public:
        /**
         * Default Constructor
         */
        SKGScheduledBoardWidget (SKGDocument* iDocument );

        /**
         * Default Destructor
         */
        virtual ~SKGScheduledBoardWidget();

private slots:
        void dataModified(const QString& iTableName, int iIdTransaction);

private:
        Q_DISABLE_COPY ( SKGScheduledBoardWidget );

        Ui::skgscheduledplugin_board ui;;
};

#endif // SKGSCHEDULEDBOARDWIDGET_H

==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/skrooge_scheduled/skgscheduledboardwidget.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSCHEDULEDBOARDWIDGET_H
#define SKGSCHEDULEDBOARDWIDGET_H
/** @file
* This file is Skrooge plugin for bank management.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/
#include "ui_skgscheduledpluginwidget_board.h"
#include "skgwidget.h"

/**
 * This file is Skrooge plugin for bank management
 */
class SKGScheduledBoardWidget : public SKGWidget
{
        Q_OBJECT

public:
        /**
         * Default Constructor
         */
        SKGScheduledBoardWidget (SKGDocument* iDocument );

        /**
         * Default Destructor
         */
        virtual ~SKGScheduledBoardWidget();

        /**
         * Get the current state
         * MUST BE OVERWRITTEN
         * @return a string containing all information needed to set the same state.
         * Could be an XML stream
         */
        virtual QString getState();

        /**
         * Set the current state
         * MUST BE OVERWRITTEN
         * @param iState must be interpreted to set the state of the widget
         */
        virtual void setState(const QString& iState);

private slots:
        void dataModified(const QString& iTableName, int iIdTransaction);
        void onOpen(const QString& iLink);

private:
        Q_DISABLE_COPY ( SKGScheduledBoardWidget );

        Ui::skgscheduledplugin_board ui;;
};

#endif // SKGSCHEDULEDBOARDWIDGET_H
